threading.Thread

threading :: Thread :: Class Thread |
[hide private]
[frames] | no frames]

# Class Thread

    object --+
             |
      _Verbose --+
                 |
                Thread

Known Subclasses:
  spoon.transports.SpoonTransport'.SpoonTransportThread

Instance Methods | [hide private]
`` | __bootstrap(self)
`` | __delete(self) Remove current thread from the dict of currently running threads.
`` | __exc_info() Return information about the most recent exception caught by an except clause in the current stack frame or in an older stack frame.
`` | __init__(self, group=None, target=None, name=None, args=(), kwargs={}, verbose=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __repr__(self) repr(x)
`` | __stop(self)
`` | _set_daemon(self)
`` | getName(self)
`` | isAlive(self)
`` | isDaemon(self)
`` | join(self, timeout=None)
`` | run(self)
`` | setDaemon(self, daemonic)
`` | setName(self, name)
`` | start(self)
Inherited from `_Verbose` (private): `_note` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __initialized = `False`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __bootstrap(self) |
None

### __delete(self) |
Remove current thread from the dict of currently running threads.

### __exc_info() |
    Return information about the most recent exception caught by an except clause in the current stack frame or in an older stack frame. Returns:
        (type, value, traceback)

### __init__(self, group=None, target=None, name=None, args=(), kwargs={}, verbose=None) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: _Verbose.__init__

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

### __stop(self) |
None

### _set_daemon(self) |
None

### getName(self) |
None

### isAlive(self) |
None

### isDaemon(self) |
None

### join(self, timeout=None) |
None

### run(self) |
None

### setDaemon(self, daemonic) |
None

### setName(self, name) |
None

### start(self) |
None

Class Variable Details | [hide private]

    ### __initialized None Value:
        False